Your message dated Thu, 28 May 2026 08:51:33 +0000
with message-id <[email protected]>
and subject line Bug#1135243: fixed in git-buildpackage 0.9.43
has caused the Debian Bug report #1135243,
regarding gbp-dch: add support to --stable and --lts
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
1135243: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1135243
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: git-buildpackage
Version: 0.9.42
Severity: wishlist
Tags: patch
Hi Guido,
I use gbp quite a lot and I'm missing --stable and --lts flags in
gbp dch, could we have that? (patch attached and MR filled on Salsa)
Cheers,
Charles
-- System Information:
Debian Release: forky/sid
APT prefers testing
APT policy: (900, 'testing'), (500, 'unstable')
Architecture: amd64 (x86_64)
Kernel: Linux 6.19.13+deb14-amd64 (SMP w/24 CPU threads; PREEMPT)
Locale: LANG=pt_BR.UTF-8, LC_CTYPE=pt_BR.UTF-8 (charmap=UTF-8),
LANGUAGE=en_US:en
Shell: /bin/sh linked to /usr/bin/dash
Init: systemd (via /run/systemd/system)
LSM: AppArmor: enabled
Versions of packages git-buildpackage depends on:
ii devscripts 2.26.7
ii git 1:2.53.0-1
ii man-db 2.13.1-1
ii python3 3.13.9-3
ii python3-dateutil 2.9.0-4
ii python3-yaml 6.0.3-1
ii sensible-utils 0.0.26
Versions of packages git-buildpackage recommends:
ii pristine-tar 1.50+nmu2
ii python3-requests 2.32.5+dfsg-1
ii sbuild 0.91.8
Versions of packages git-buildpackage suggests:
pn python3-notify2 <none>
ii sudo 1.9.17p2-5
ii unzip 6.0-29
-- no debconf information
>From 0dd236f0bd025fbcaa7da87c38208b65c87c1a8a Mon Sep 17 00:00:00 2001
From: Carlos Henrique Lima Melara <[email protected]>
Date: Wed, 29 Apr 2026 22:12:44 -0300
Subject: [PATCH] dch: Add support to --stable and --lts options
Signed-off-by: Carlos Henrique Lima Melara <[email protected]>
---
debian/zsh/_gbp | 2 ++
docs/manpages/gbp-dch.xml | 24 ++++++++++++++++++++++++
gbp/scripts/dch.py | 13 ++++++++++++-
3 files changed, 38 insertions(+), 1 deletion(-)
diff --git a/debian/zsh/_gbp b/debian/zsh/_gbp
index 2d908b91..d97bc52c 100644
--- a/debian/zsh/_gbp
+++ b/debian/zsh/_gbp
@@ -153,6 +153,8 @@ _gbp-dch () {
'--bpo[Increment the release number for a backports upload]' \
'--nmu[Increment the release number for a NMU upload]' \
'--qa[Increment the release number for a QA upload]' \
+ '--lts[Increment the release number for a LTS upload]' \
+ '--stable[Increment the release number for an upload to the current stable release]' \
'(--local -l)'{-l,--local}'=-[Increment the release number for a local build]' \
'--distribution=-[Set the distribution field]' \
'--force-distribution[Force distribution]' \
diff --git a/docs/manpages/gbp-dch.xml b/docs/manpages/gbp-dch.xml
index 129d5117..c88559c7 100644
--- a/docs/manpages/gbp-dch.xml
+++ b/docs/manpages/gbp-dch.xml
@@ -49,6 +49,8 @@
<arg><option>--qa</option></arg>
<arg><option>--security</option></arg>
<arg><option>--team</option></arg>
+ <arg><option>--lts</option></arg>
+ <arg><option>--stable</option></arg>
<arg><option>--local=</option><replaceable>suffix</replaceable></arg>
</group>
<arg><option>--distribution=</option><replaceable>name</replaceable></arg>
@@ -384,6 +386,28 @@
</para>
</listitem>
</varlistentry>
+ <varlistentry>
+ <term><option>--lts</option>
+ </term>
+ <listitem>
+ <para>
+ Increment the Debian release number for a Debian LTS Team upload, and
+ add a LTS upload changelog comment.
+ This option can't be set via &gbp.conf;.
+ </para>
+ </listitem>
+ </varlistentry>
+ <varlistentry>
+ <term><option>--stable</option>
+ </term>
+ <listitem>
+ <para>
+ Increment the Debian release number for an upload to the
+ current stable release.
+ This option can't be set via &gbp.conf;.
+ </para>
+ </listitem>
+ </varlistentry>
<varlistentry>
<term><option>--local=</option><replaceable>suffix</replaceable>,
<option>-l</option> <replaceable>suffix</replaceable>
diff --git a/gbp/scripts/dch.py b/gbp/scripts/dch.py
index 28647a2f..3da85bcd 100644
--- a/gbp/scripts/dch.py
+++ b/gbp/scripts/dch.py
@@ -397,6 +397,12 @@ def build_parser(name):
version_group.add_option("--security", dest="security", action="store_true", default=False,
help="Increment the Debian release number for a security upload and "
"add a security upload changelog comment.")
+ version_group.add_option("--lts", dest="lts", action="store_true", default=False,
+ help="Increment the Debian release number for a LTS Team upload, "
+ "and add a LTS upload changelog comment.")
+ version_group.add_option("--stable", dest="stable", action="store_true", default=False,
+ help="Increment the Debian release number for an upload to "
+ "the current stable release.")
version_group.add_option("-l", "--local", dest="local_suffix", metavar="SUFFIX",
help="Add a suffix to the Debian version number for a local build.")
version_group.add_boolean_config_file_option(option_name="git-author", dest="use_git_author")
@@ -510,7 +516,8 @@ def main(argv):
add_section = False
# add a new changelog section if:
if (options.new_version or options.bpo or options.nmu or options.qa or
- options.team or options.security or options.local_suffix):
+ options.team or options.security or options.lts or options.stable or
+ options.local_suffix):
if options.bpo:
version_change['increment'] = '--bpo'
elif options.nmu:
@@ -521,6 +528,10 @@ def main(argv):
version_change['increment'] = '--team'
elif options.security:
version_change['increment'] = '--security'
+ elif options.lts:
+ version_change['increment'] = '--lts'
+ elif options.stable:
+ version_change['increment'] = '--stable'
elif options.local_suffix:
version_change['increment'] = '--local=%s' % options.local_suffix
else:
--
2.53.0
--- End Message ---
--- Begin Message ---
Source: git-buildpackage
Source-Version: 0.9.43
Done: Guido Günther <[email protected]>
We believe that the bug you reported is fixed in the latest version of
git-buildpackage, which is due to be installed in the Debian FTP archive.
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Guido Günther <[email protected]> (supplier of updated git-buildpackage package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512
Format: 1.8
Date: Tue, 26 May 2026 09:12:52 +0200
Source: git-buildpackage
Architecture: source
Version: 0.9.43
Distribution: unstable
Urgency: medium
Maintainer: Guido Günther <[email protected]>
Changed-By: Guido Günther <[email protected]>
Closes: 1132914 1135243
Changes:
git-buildpackage (0.9.43) unstable; urgency=medium
.
[ Arnaud Rebillout ]
* [06dba64] Fix _cmd_has_feature.
.
[ Guido Günther ]
* [714dbf8] ci: Disable uscan. It's a Debian native package
* [5b9ced3] pq: Allow to disable copy detection (Closes: #1132914)
* [3bff95c] tmpfile: Add type annotations.
Fixes build with mypy 2.1.0
.
[ Bastian Triller ]
* [3aaabca] docs/import: Fix typo
.
[ Carlos Henrique Lima Melara ]
* [6da9dbe] dch: Add support to --stable and --lts options (Closes: #1135243)
Checksums-Sha1:
4815a25c5a446e42a28b0917ad521bf54892fbec 2309 git-buildpackage_0.9.43.dsc
b66e1a1118d1e2fa4938834ac401f4555cc2138c 3867720 git-buildpackage_0.9.43.tar.xz
549b92b15fc781aca67d052ea99636b9669f8a18 13718
git-buildpackage_0.9.43_amd64.buildinfo
Checksums-Sha256:
c2c67984e7215edc45c93a3f2dd99ab395d8250f376e380ea521dfb37301a1e2 2309
git-buildpackage_0.9.43.dsc
9b4cc4150691c7a9f495a478d80ef919d25ccdfb049ba246500b74075a08d883 3867720
git-buildpackage_0.9.43.tar.xz
519f34664370b8e62dfad01987e199c89226a5fa6d8a0d590c73f4195bb005e8 13718
git-buildpackage_0.9.43_amd64.buildinfo
Files:
b7dfd84539ed2da64fb016a96b9890c1 2309 vcs optional git-buildpackage_0.9.43.dsc
1cf5bbe91f8854e44857802e8d8f3ecc 3867720 vcs optional
git-buildpackage_0.9.43.tar.xz
bb360429d7d52c9efa503037854fcc65 13718 vcs optional
git-buildpackage_0.9.43_amd64.buildinfo
-----BEGIN PGP SIGNATURE-----
iQIzBAEBCgAdFiEEY/bM35YinQkoayrDJb+GUkr8weMFAmoX88YACgkQJb+GUkr8
wePNkw//ZDBjs80GnCjBRGsxuWyDCF9YzZPbq0tCc/EQDZuTFIkxwU/PCYDOeF3H
vNEoSTDNweViFEFHge3cXN/GC/i6dhcGIGzZl13cj/Ll5hW3z545n+8BHQS/2iPS
RLadgFeXKIRJJW7mdMJ6j8rZPxEuY6qWQznUQKVoeUOGJDmSMLHWAP9mcaQjIc+H
0esNUppyWUBl6B5WBpnh1wqmwNuZSbOly3oVRMQnNJr5oIyhwLNo/fUh4yHH5cLd
+++hIhdZ1yk6y2jgt5NpSj2N9wAT2qVRP+gR8lAXmf4g5UzQ9X2BRu6Y6c+yJVAW
V9iciQAXWJ1lW7EsS2q0H4HVsemzKDrCOb9R2MAPkJTh3ppk7sqyQmhMeTEj//WG
LRxnsFdsJU8xDmadwqlEq+MAWnkUu1DIPFHivhVhz3jZXvzqPwVySZ7WWqxd2tgz
DDHpD9U28XFGXwz5HZihBLW2weeTPzmvuJta3RwEcJ6mlDBbxTcbT8LRQe9fvCDq
rUQsJ41OvmndmVkppfosQ1jbmZQ2+7p6e+QJ2Kuwbyqqv3dFN3pjdFq0XfZ7W3Vb
xx0vK/lJq6M84vJ4ikc5ZrkE1BQSv5c/Ngw/U7cQIbXvKi48mFcmwSuPTx0XFr/7
7Tg8aMJW0gbQrRVdu14AUTKuOFLVWEEEOKG96e421ooDPIClAtE=
=ICSd
-----END PGP SIGNATURE-----
pgpuTT77ThCEF.pgp
Description: PGP signature
--- End Message ---